@@ -46,7 +46,7 @@ def multiload(locations):
        >>> from modelicares import *
 
        # By file:
-       >>> multiload(['examples/ChuaCircuit', 'examples/PID']) # doctest: +ELLIPSIS
+       >>> multiload(['examples/ChuaCircuit.mat', 'examples/PID']) # doctest: +ELLIPSIS
        Valid: SimRes('...ChuaCircuit.mat')
        Valid: LinRes('...PID.mat')
        ([SimRes('...ChuaCircuit.mat')], [LinRes('...PID.mat')])
@@ -54,9 +54,9 @@ def multiload(locations):
        # By directory:
        >>> multiload('examples') # doctest: +ELLIPSIS
        Valid: SimRes('...ChuaCircuit.mat')
-       Valid: SimRes('...ChuaCircuit2.mat')...
        Valid: LinRes('...PID.mat')...
-       ([SimRes('...ChuaCircuit.mat'), SimRes('...ChuaCircuit2.mat'), SimRes('...ThreeTanks.mat')], [LinRes('...PID.mat')])
+       Valid: SimRes('...ThreeTanks.mat')
+       ([SimRes('...ChuaCircuit.mat'), SimRes('...ThreeTanks.mat')], [LinRes('...PID.mat')])
     """
 
     # Make a list of files.
@@ -89,7 +89,7 @@ def multiload(locations):
     return sims, lins
 
 
-def multiplot(sims, suffixes, dashes=[(1, 0), (3, 3), (1, 1), (3, 2, 1, 2)],
+def multiplot(sims, suffixes='', dashes=[(1, 0), (3, 3), (1, 1), (3, 2, 1, 2)],
               **kwargs):
     """Plot data from multiple simulations in 2D Cartesian coordinates.
 
@@ -106,6 +106,9 @@ def multiplot(sims, suffixes, dashes=[(1, 0), (3, 3), (1, 1), (3, 2, 1, 2)],
     - *suffixes*: Suffix or list of suffixes for the legends (see
       :meth:`simres.SimRes.plot`)
 
+         If *suffixes* is None, then no suffix will be used.  If it is *None*,
+         then the base filenames will be used.
+
     - *\*\*kwargs*: Propagated to  :meth:`simres.SimRes.plot` (and thus to
       :meth:`base.plot` and finally :meth:`matplotlib.pyplot.plot`)
 
@@ -119,14 +122,16 @@ def multiplot(sims, suffixes, dashes=[(1, 0), (3, 3), (1, 1), (3, 2, 1, 2)],
 
     .. code-block:: python
 
+       >>> from glob import glob
        >>> from modelicares import SimRes, multiplot, saveall
 
-       >>> sims = map(SimRes, ['examples/ChuaCircuit', 'examples/ChuaCircuit2'])
+       >>> sims = map(SimRes, glob('examples/ChuaCircuit/*/*.mat'))
        >>> multiplot(sims, title="Chua Circuit", label='examples/ChuaCircuits',
        ...           suffixes=['L.L = %.0f H' % sim.get_IV('L.L')
        ...                     for sim in sims], # Read legend parameters.
        ...           ynames1='L.i', ylabel1="Current") # doctest: +ELLIPSIS
        (<matplotlib.axes.AxesSubplot object at 0x...>, None)
+
        >>> saveall()
        Saved examples/ChuaCircuits.pdf
        Saved examples/ChuaCircuits.png
@@ -151,6 +156,13 @@ def multiplot(sims, suffixes, dashes=[(1, 0), (3, 3), (1, 1), (3, 2, 1, 2)],
         dashes = cycle(dashes)
     kwargs['dashes'] = dashes
 
+    # Process the suffixes input.
+    if suffixes == '':
+        suffixes = [sim.fbase for sim in sims]
+    elif suffixes == None:
+        suffixes = ['']*len(sims)
+
+    # Generate the plots.
     try:
         ax1, ax2 = sims[0].plot(suffix=suffixes[0], **kwargs)
         kwargs.update({'ax1': ax1, 'ax2': ax2})
